=== modified file 'bzrlib/selftest/teststore.py'
--- bzrlib/selftest/teststore.py	2005-10-17 00:11:49 +0000
+++ bzrlib/selftest/teststore.py	2005-10-17 00:46:10 +0000
@@ -270,8 +270,8 @@
         my_store.add(stream, "foo", 'dsc')
         self.assertEqual([("_add", "45/foo.dsc", stream)], my_store._calls)
 
-    def get_populated_store(self, prefixed=False):
-        my_store = TextStore(MemoryTransport(), prefixed)
+    def get_populated_store(self, prefixed=False, store_class=TextStore):
+        my_store = store_class(MemoryTransport(), prefixed)
         my_store.register_suffix('sig')
         stream = StringIO("signature")
         my_store.add(stream, "foo", 'sig')
@@ -318,3 +318,27 @@
         my_store = self.get_populated_store(True)
         self.assertEqual('signature for missing base',
                          my_store.get('missing', 'sig').read())
+
+    def test___iter__no_suffix(self):
+        my_store = TextStore(MemoryTransport(), False)
+        stream = StringIO("content")
+        my_store.add(stream, "foo")
+        self.assertEqual(set(['foo']),
+                         set(my_store.__iter__()))
+
+    def test___iter__(self):
+        self.assertEqual(set(['foo']),
+                         set(self.get_populated_store().__iter__()))
+        self.assertEqual(set(['foo']),
+                         set(self.get_populated_store(True).__iter__()))
+
+    def test___iter__compressed(self):
+        self.assertEqual(set(['foo']),
+                         set(self.get_populated_store(
+                             store_class=CompressedTextStore).__iter__()))
+        self.assertEqual(set(['foo']),
+                         set(self.get_populated_store(
+                             True, CompressedTextStore).__iter__()))
+
+    def test___len__(self):
+        self.assertEqual(1, len(self.get_populated_store()))

=== modified file 'bzrlib/store/__init__.py'
--- bzrlib/store/__init__.py	2005-10-17 00:11:49 +0000
+++ bzrlib/store/__init__.py	2005-10-17 00:46:10 +0000
@@ -24,6 +24,7 @@
 unique ID.
 """
 
+import os
 from cStringIO import StringIO
 from zlib import adler32
 
@@ -242,6 +243,20 @@
         self._prefixed = prefixed
         self._suffixes = set()
 
+    def __iter__(self):
+        for relpath in self._transport.iter_files_recursive():
+            # worst case is one of each suffix.
+            name = os.path.basename(relpath)
+            if name.endswith('.gz'):
+                name = name[:-3]
+            skip = False
+            for count in range(len(self._suffixes)):
+                for suffix in self._suffixes:
+                    if name.endswith('.' + suffix):
+                        skip = True
+            if not skip:
+                yield name
+
     def __len__(self):
         return len(list(self.__iter__()))
 

=== modified file 'bzrlib/store/compressed_text.py'
--- bzrlib/store/compressed_text.py	2005-10-16 23:50:29 +0000
+++ bzrlib/store/compressed_text.py	2005-10-17 00:46:10 +0000
@@ -21,7 +21,7 @@
 do any sort of delta compression.
 """
 
-import os, tempfile, gzip
+import gzip
 
 import bzrlib.store
 from bzrlib.trace import mutter
@@ -112,13 +112,6 @@
         super(CompressedTextStore, self).__init__(transport, prefixed)
         self.register_suffix('gz')
 
-    def __iter__(self):
-        for relpath in self._transport.iter_files_recursive():
-            if relpath.endswith(".gz"):
-                yield os.path.basename(relpath)[:-3]
-            else:
-                yield os.path.basename(relpath)
-
     def _get(self, filename):
         """Returns a file reading from a particular entry."""
         f = self._transport.get(filename)

=== modified file 'bzrlib/store/text.py'
--- bzrlib/store/text.py	2005-10-16 14:19:24 +0000
+++ bzrlib/store/text.py	2005-10-17 00:46:10 +0000
@@ -21,8 +21,6 @@
 do any sort of delta compression.
 """
 
-import os, tempfile
-
 import bzrlib.store
 from bzrlib.store import hash_prefix
 from bzrlib.trace import mutter
@@ -47,10 +45,6 @@
     def _get(self, fn):
         return self._transport.get(fn)
 
-    def __iter__(self):
-        for relpath in self._transport.iter_files_recursive():
-            yield os.path.basename(relpath)
-
 
 def ScratchTextStore():
     return TextStore(ScratchTransport())

